@@ -463,24 +463,10 @@ Type ^H^H^H (Control-h Control-h Control-h) to get more help options.\n")
 
     (if load-user-init-file-p
 	(maybe-migrate-user-init-file))
-    ;;####FSFmacs junk
-    ;;      (or menubar-bindings-done
-    ;;	  (precompute-menubar-bindings))
+    ;; FSF calls precompute-menubar-bindings.  We don't mix menubars
+    ;; and keymaps.
     ))
 
-;;####FSFmacs junk
-;;; Precompute the keyboard equivalents in the menu bar items.
-;;(defun precompute-menubar-bindings ()
-;;  (if (eq window-system 'x)
-;;      (let ((submap (lookup-key global-map [menu-bar])))
-;;	(while submap
-;;	  (and (consp (car submap))
-;;	       (symbolp (car (car submap)))
-;;	       (stringp (car-safe (cdr (car submap))))
-;;	       (keymapp (cdr (cdr (car submap))))
-;;	       (x-popup-menu nil (cdr (cdr (car submap)))))
-;;	  (setq submap (cdr submap))))))
-
 (defun command-line-early (args)
   ;; This processes those switches which need to be processed before
   ;; starting up the window system.
@@ -591,6 +577,9 @@ If this is nil, no message will be displayed.")
       ;; handled here instead of down in C.
       (setq command-line-args-left (command-line-early command-line-args-left))
 
+      (when (eq system-type 'windows-nt)
+	(init-mswindows-at-startup))
+
       ;; Setup the toolbar icon directory
       (when (featurep 'toolbar)
 	(init-toolbar-location))
@@ -794,11 +783,11 @@ directory which will load the relocated initialization code.")
   (if (not user-init-file)
       (setq user-init-file
 	    (find-user-init-file user-init-directory)))
+  (if (not custom-file)
+      (setq custom-file (make-custom-file-name user-init-file)))
   (if (and user-init-file
 	   (file-readable-p user-init-file))
       (load user-init-file t t t))
-  (if (not custom-file)
-      (setq custom-file (make-custom-file-name user-init-file)))
   (if (and custom-file
 	   (or (not user-init-file)
 	       (not (string= custom-file user-init-file)))
@@ -1124,11 +1113,11 @@ XEmacs, by either running the command `xemacs-mule', or by using the X resource
       ": how to get the latest version\n")
      "\n--\n"
      (face italic "\
-Copyright (C) 1985-1999 Free Software Foundation, Inc.
+Copyright (C) 1985-2001 Free Software Foundation, Inc.
 Copyright (C) 1990-1994 Lucid, Inc.
 Copyright (C) 1993-1997 Sun Microsystems, Inc. All Rights Reserved.
 Copyright (C) 1994-1996 Board of Trustees, University of Illinois
-Copyright (C) 1995-1996 Ben Wing\n"))
+Copyright (C) 1995-2001 Ben Wing\n"))
 
     ((face (blue bold underline) "\nInformation, on-line help:\n\n")
      "XEmacs comes with plenty of documentation...\n\n"
